summaryrefslogtreecommitdiff
path: root/cli/cli/context.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'cli/cli/context.hxx')
-rw-r--r--cli/cli/context.hxx13
1 files changed, 10 insertions, 3 deletions
diff --git a/cli/cli/context.hxx b/cli/cli/context.hxx
index 66dcb24..c5802ed 100644
--- a/cli/cli/context.hxx
+++ b/cli/cli/context.hxx
@@ -92,6 +92,8 @@ public:
string const& opt_prefix;
string const& opt_sep;
string const& cli;
+ string const& exp;
+ string const& exp_inl; // Export symbol if inline is suppressed.
typedef std::map<string, string> reserved_name_map_type;
reserved_name_map_type const& reserved_name_map;
@@ -135,6 +137,8 @@ private:
{
string inl_;
string cli_;
+ string exp_;
+ string exp_inl_;
keyword_set_type keyword_set_;
regex_mapping link_regex_;
id_set_type id_set_;
@@ -153,10 +157,13 @@ public:
string
process_link_target (const string&);
// Translate and format the documentation string. Translate converts
// the <arg>-style constructs to \i{arg}. Format converts the string
// to the output format.
//
+ static void
+ preprocess_ascii_tree (string&);
+
static string
translate_arg (string const&, std::set<string>&);
@@ -153,10 +157,13 @@ public:
string
process_link_target (const string&);
- // Translate and format the documentation string. Translate converts
- // the <arg>-style constructs to \i{arg}. Format converts the string
- // to the output format.
+ // Preprocess, translate, and format the documentation string. Translate
+ // converts the <arg>-style constructs to \i{arg}. Format converts the
+ // string to the output format.
//